@@ -7,5 +7,6 @@ get_boundary <- function(content_type){
 
   # Extract bounary
   m <- regexpr('boundary=[^; ]{2,}', content_type, ignore.case = TRUE)
-  sub('boundary=','',regmatches(content_type, m)[[1]])
+  boundary <- sub('boundary=','',regmatches(content_type, m)[[1]])
+  sub('^"(.*)"$', "\\1", boundary)
 }
